@@ -1,6 +1,6 @@
 ### IAG versus ESAG
 iagesag <- function(x, B = 1, tol = 1e-07) {
-  mod <- Directional::ESAGmle(x, tol = tol)
+  mod <- Directional::esag.mle(x, tol = tol)
   stat <- 2 * mod$loglik - 2 * mod$iag.loglik
   if (B == 1) {
     pvalue <- pchisq(stat, 2, lower.tail = FALSE)
@@ -11,7 +11,7 @@ iagesag <- function(x, B = 1, tol = 1e-07) {
     n <- dim(x)[1]
     for (i in 1:B) {
       nu <- sample(n, n, replace = TRUE)
-	    mod <- Directional::ESAGmle(x[nu, ], tol = tol)
+	    mod <- Directional::esag.mle(x[nu, ], tol = tol)
       tb[i] <- 2 * mod$loglik - 2 * mod$iag.loglik
     }
     res <- c( stat, (sum(tb > stat) + 1) / (B + 1) )
