@@ -25,7 +25,7 @@ kuiper <- function(u, rads = FALSE, R = 1) {
     pvalue <- sum(b1 - b2)
   } else {
     x <- matrix( runif(n * R, 0, 2 * pi), ncol = R)
-    x <- Rfast::sort_mat(x) / (2 * pi)
+    x <- Rfast::colSort(x) / (2 * pi)
     bvn <- f * ( Rfast::colMaxs(x - (i - 1)/n, value = TRUE) + Rfast::colMaxs(i/n - x, value = TRUE) )
     pvalue <- ( sum(bvn > Vn) + 1 ) / (R + 1)
   }
